@@ -34,7 +34,7 @@ class AbstractBackend(EventEmitter):
     ERR_CONNECTION_TIMEOUT = 2
     ERR_NOT_SUPPORTED = 3
     ERR_SERVER_FULL = 4
-
+    
     EVENT_STARTED = "event-started"
     EVENT_KILLED = "event-killed"
     EVENT_SUSPENDED = "event-suspended"
@@ -328,11 +328,18 @@ class AbstractBackend(EventEmitter):
 
         filelines = [ l for l in data.splitlines()
                       if l.startswith("File") ]
+        httplines = [ l for l in data.splitlines()
+                      if l.startswith("http") ]
         for line in filelines:
             idx = line.find("=")
             uri = line[idx + 1:].strip()
             uris.append(uri)
-        #end for    
+        #end for
+
+        for line in httplines:
+            uri = line.strip()
+            uris.append(uri)
+        #end for
 
         return uris
 
